

clear all
close all

%% NOTES %%

% Script for Puget Sound analysis

% Input parameters: Seasonal food availability (mean, peak, amplitude), seasonal energetic costs, constant mortality (3 levels)
% Output: Plots for 10 000 individuals following the predicted optimal strategies for parameter values representative of Pacific herring in Puget Sound

%% PARAMETERS %%

maxyear = 10; %years of simulation
T=365*maxyear; %in days
EMax = 11; %resolution of environmental stochasticity

% Migrationduration
migrationduration= 20; %days

%%%%% PARAMETERS FOR LOOPS %%%%

% FOOD AVAILABILITY (values for annual sine curve; here called surplus)

%artificial vectors to allow script to be run
amplitude_surplus = [1 1 1];
mean_surplus = [1 1 1];

% Max and min food availability
max_surplus = [20000 22000 24000];
min_surplus = [0 0 0];

% Peak day for food availability in steps
surplus_peakday_start = 30;
surplus_peakday_end = 335;
surplus_peakday_steps = 7;
surplus_peakday_stepsize = floor((surplus_peakday_end-surplus_peakday_start)/(surplus_peakday_steps-1));
surplus_peakday = surplus_peakday_start:surplus_peakday_stepsize:surplus_peakday_end;

% ENERGETIC COSTS

% Feeding ground (annual sine curve)
fcost_min_value = 4900;
fcost_max_value = 8500;
fcost_peak_day = 212;
energeticcost_f = sinecurve_function_2(fcost_min_value,fcost_max_value,fcost_peak_day,T+1+2*migrationduration);

% Migration
energeticcost_m = energeticcost_f + 0.5*fcost_min_value;

% Spawning ground
energeticcost_s = energeticcost_f;

% MORTALITY RATE (3 levels)

% Feeding ground
fmortality = [0.3/365 0.5/365 0.7/365];
FM_peakday = 100;

% OFFSPRING FITNESS (annual sine curve)

OF_min = 0;
OF_max = 0.8;
OF_peakday = 91;
offspringfitness = sinecurve_function_2(OF_min,OF_max,OF_peakday,T+1+2*migrationduration);


% Environmental stochasticity
AutoCorr = 0.95; %autocorrelation coefficient
StochScale = 1.5; %variance scaler
EMean = 1+(EMax-1)/2;
E_real = EMean;
E_cat = round(E_real);
pE(1:EMax,1:EMax) = 0;
EffectOfE = 0.5;
sumE_cat = 0;
for Counter= 1:20000;
    nextE_real = autocorrelatedE(E_real,EMax,1,EMean,AutoCorr,StochScale);
    E_real = nextE_real;
    nextE_cat = round(nextE_real);
    pE(nextE_cat,E_cat) = pE(nextE_cat,E_cat) + 1;
    sumE_cat = sumE_cat + nextE_cat;
    E_cat = nextE_cat;
end
ActualMeanEnvironment = sumE_cat/20000;

% pAllE(:) - probability of being in each E category, E_cat (irrespective of preceeding category)
for E_cat=1:EMax
    pAllE(E_cat) = sum(pE(E_cat,:));
end
pAllE(:) = pAllE(:)/sum(pAllE(:));

% Use pE matrix - probability of next category depending on current category (E_cat*) given by pE(:,E_cat*) - for autocorrelated fitness
% calculations dependent on current environment, E_cat*
for E_cat=1:EMax
    sumpE = sum(pE(:,E_cat));
    if (sumpE > 0)
        pE(:,E_cat) = pE(:,E_cat)/sumpE; %probability of the next E_cat being a certain value given current E_cat value
    end
end

% ValueE(1:EMax) - used to scale food availability feeding(t) to be stochastic
ValueE(1:EMax) = 1+EffectOfE*(2*(((1:EMax)-1)/(EMax-1))-1); %creates an array of length EMax with values from 0.5-1.5


% OTHER PARAMETERS

%Energy reserves and resolution
xmin = 0; %x = reserve state, for energetics or reproduction
xmax = 1480000; %max possible energy reserves in Joules
xcat_max = 101; %Steps/categories

%Fitness for optimization algorithm (here all future descendants in Joules)
F(1:EMax,1:xcat_max,1:2,1:T+1+2*migrationduration) = 0.; %all future descendants (J); habitat 1=feeding, 2=spawning
Vf(1:EMax,1:xcat_max,1:T+1+2*migrationduration) = 0.; %fitness value if staying on feeding ground (J)

%Clutch size - for conversion to a categorical variable
cmin = 0;
cmax = xmax;
ccat_max = 20 + 1; % 1/x steps plus spawn everything

%Strategies: 1=at feeding ground, migrate (1) or not (0), 2=at spawning ground, spawn everything (e.g. 21), something (e.g. 1-20), or wait (0)
strategy(1:EMax,1:xcat_max,1:2,365*10) = 0;

%Matrices for storing values for plotting
maxind = 1000;
surpluspeak_SD(365*length(surplus_peakday),length(fmortality),length(mean_surplus),length(amplitude_surplus)) = NaN;
surpluspeak_SD_frequency(365*length(surplus_peakday),length(fmortality),length(mean_surplus),length(amplitude_surplus)) = NaN;
surpluspeak_SD_energy(365*length(surplus_peakday),length(fmortality),length(mean_surplus),length(amplitude_surplus)) = NaN;
surpluspeak_plotX(365*length(surplus_peakday),length(fmortality),length(mean_surplus),length(amplitude_surplus)) = NaN;
dead_initial_scen(length(surplus_peakday),length(fmortality),length(mean_surplus),length(amplitude_surplus))  = 0;


%% BACKWARD SIMULATION %%

% Loops for obtaining and storing means and variances for predicted mean spawning day for different peak days in food availability
% under 3 levels of mortality rate

for FMvalue = 1:length(fmortality)
    for Mean = 1:length(mean_surplus)
        for Ampl = 1:length(amplitude_surplus)
            surplus_min = min_surplus(Mean);
            surplus_max = max_surplus(Mean);
            
            for FIpeak = 1:length(surplus_peakday)
                mortality_f = sinecurve_function_2(fmortality(FMvalue),fmortality(FMvalue),FM_peakday,T+1+2*migrationduration);
                mortality_m = mortality_f;
                mortality_s = mortality_f;
                feeding = sinecurve_function_2(surplus_min,surplus_max,surplus_peakday(FIpeak),T+1+2*migrationduration);
                net_intake = feeding - energeticcost_f;
                
                dead_initial = 0;
                SD_all_ind = 0;
                sum_spawndays_ind(365,maxind) = 0;
                sum_energy_ind(365,maxind) = 0;
                max_energy_ind(365,maxind) = 0;
                
                %Start backward simulation
                for t = T:-1:1
                    for xcat = 1:xcat_max
                        x = xmin + (xmax-xmin)*((xcat-1)/(xcat_max-1)); %J, Makes a continous variable x for every xcat of value xcat-1 (0-100)
                        
                        %Fitness if migrating
                        reservesatarrival = x - sum(energeticcost_m(t:t+migrationduration)); %J, reserves at arrival at spawning grounds
                        newx_cat_0 = ((reservesatarrival-xmin)/(xmax-xmin))*(xcat_max-1)+1;
                        intx_0 =  max(1,min(floor(newx_cat_0),xcat_max-1));
                        dx_0 = max(0,min(newx_cat_0-intx_0,1));
                        Vm(xcat,t) = exp(-sum(mortality_m(t:t+migrationduration)))*((1-dx_0).*F(1,intx_0,2,t+migrationduration) + dx_0.*F(1,intx_0+1,2,t+migrationduration));  %migrate, arrive with lower stores, and get fitness from spawning ground at arrival time
                        
                        % Fitness if feeding
                        newx(1:EMax) = min(x + ValueE(:)*feeding(t) - energeticcost_f(t),xmax);
                        newx_cat(1:EMax) = ((newx(:)-xmin)/(xmax-xmin))*(xcat_max-1)+1; %Makes a category variable newx_cat of value newx+1, to get the right value in the fitnessmatrix F, which is F(xcat,t)
                        intx(1:EMax) = max(1,min(floor(newx_cat(:)),xcat_max-1));
                        dx(1:EMax) = max(0,min(newx_cat(:)-intx(:),1));
                        
                        for E_cat = 1:EMax  %Has to be calculated for each value of the current environment
                            if (newx(E_cat) >= 0)
                                % Not only the feeding intake but also the fitness is autocorrelated as opposed to random
                                Vf(E_cat,xcat,t) = exp(-mortality_f(t)).*sum(pE(:,E_cat).*((1-dx(E_cat)).*F(:,intx(E_cat),1,t+1) + dx(E_cat).*F(:,intx(E_cat)+1,1,t+1)));  %Interpolate F due to continuous state variable newx - updated with habitat
                                %For the current E_cat* the probablity of the previous E_cat (in future) for each E_cat is pE(E_cat,E_cat*) - in the line above
                                %we sum the fitness value for each E_cat discounted by the probability of having had that fitness value (ie. of having been in that E_cat)
                            else
                                Vf(E_cat,xcat,t) = 0;  %Starvation
                            end
                            % Check whether to migrate or not
                            if Vm(xcat,t) > Vf(E_cat,xcat,t)  %Migrate to spawning ground if expected fitenss is higher than that of staying at feeding ground (given current E)
                                F(E_cat,xcat,1,t) = Vm(xcat,t);
                                strategy(E_cat,xcat,1,t) = 1;
                            else
                                F(E_cat,xcat,1,t) = Vf(E_cat,xcat,t);
                                strategy(E_cat,xcat,1,t) = 0;
                            end
                        end %E_cat loop
                        
                        % Fitness if spawning, c=energetic investment into clutch
                        spawneverything = x; %max energy available for spawning (J)
                        spawnandreturn  = x - sum(energeticcost_m(t:t+migrationduration));  %return to feeding ground - max energy available for spawning (J)
                        
                        % Default assumption - no spawning is possible
                        optimalfitness = 0;
                        optimalc_cat = 0;
                        
                        % Spawning possible - check max fitness
                        
                        % Fitness value of spawning and returning to feeding ground
                        Vs(1:ccat_max) = 0;  %Fitness if spawning
                        
                        % Fish spawns everything and dies - future fitness not included
                        if spawneverything > 0
                            Vs(ccat_max) = spawneverything*offspringfitness(t) + 0;  %0 because future fitness is null
                        end
                        % Fish stores energy to swim back to feeding grounds - future fitness included
                        if spawnandreturn > 0
                            for c_cat = 1:ccat_max-1
                                c = ((c_cat)/(ccat_max-1))*spawnandreturn;  %clutch size (J)
                                newx_0 = spawnandreturn - c;   %x when back at feeding ground
                                newx_cat_0 = ((newx_0-xmin)/(xmax-xmin))*(xcat_max-1)+1;
                                intx_0 = max(1,min(floor(newx_cat_0),xcat_max-1));
                                dx_0 = max(0,min(newx_cat_0-intx_0,1));
                                Vs(c_cat) = c*offspringfitness(t) + ...   %value of current spawning
                                    exp(-sum(mortality_m(t:t+migrationduration)))* ...   %survival until back at feeding grounds
                                    sum(pAllE(:).*((1-dx_0)*F(:,intx_0,1,t+migrationduration) + dx_0*F(:,intx_0+1,1,t+migrationduration)));
                                %Interpolate F (when back at feeding ground) due to continuous state variable newx -
                                %In the line above we sum the fitness value for each E_cat discounted by the probability
                                %of having that fitness value given by pAllE(:)
                            end
                        end
                        
                        % Optimize spawning strategy
                        [optimalfitness,optimalc_cat] = max(Vs(:));
                        
                        % Fitness value of waiting at spawning ground
                        newx_0 = x - energeticcost_s(t);   %Find x after cost of staying one time step at spawning grounds
                        newx_cat_0 = ((newx_0-xmin)/(xmax-xmin))*(xcat_max-1)+1;
                        intx_0 = max(1,min(floor(newx_cat_0),xcat_max-1));
                        dx_0 = max(0,min(newx_cat_0-intx_0,1));
                        Vw = exp(-mortality_s(t)) * ((1-dx_0)*F(1,intx_0,2,t+1) + dx_0*F(1,intx_0+1,2,t+1));
                        
                        % Check for optimal strategy at feeding ground
                        if optimalfitness >= Vw;  %fitness value of spawning is greater than not to spawn
                            F(1,xcat,2,t) = optimalfitness;
                            strategy(1,xcat,2,t) = optimalc_cat;
                        else
                            F(1,xcat,2,t) = Vw;  %fitness value of not spawning is greater than that of spawning
                            strategy(1,xcat,2,t) = 0;
                        end
                    end  %xcat
                end  %t
                
                
                
                %% FORWARD SIMULATION MONTE CARLO SIMULATION %%
                
                yrs_simulated = 20;
                tmax=365*yrs_simulated;
                maxind=10000;
                
                % Matrix of individual values for number of maxind individuals
                Ind(1:10,1:tmax+1,1:maxind) = 0;
                Ind( 1,1,:) = 1*xmax;  %initial reserve state --> aquired reserve state
                Ind( 2,1,:) = 0;   %strategy - stay on feeding ground = 10, migrate = 11, wait on spawning ground = 20, spawn = 22, spawn everything = 23
                Ind( 3,1,:) = 1;   %survival
                Ind( 4,1,:) = 0;   %proportion of cmax actually spawned at t
                Ind( 5,1,:) = 0;   %energy actually spawned at t, J
                Ind( 6,1,:) = 0;   %feeding intake
                Ind( 7,1,:) = 0;   %optimal clutch as proportion of cmax, 2 indicates terminal spawning (ccat=21)
                Ind( 8,1,:) = 0;   %energetic cost
                Ind( 9,1,:) = 0;   %cumulative fitness: summed(survival*energyspawned*offspringfitness)
                Ind(10,1,:) = 0;   %environmental value
                Ind(11,1,:) = 1;   %location, 1=feeding ground, 11=migrating from feeding ground; 2=spawning ground, 21=migrating from spawning ground
                
                for i=1:1:maxind
                    
                    E_real = EMean; %start simulation in the mean food environment for each individual
                    t = 1;
                    while t<(tmax-2*migrationduration)
                        E_real = autocorrelatedE(E_real,EMax,1,EMean,AutoCorr,StochScale);
                        Ind(10,t,i) = E_real;
                        Loc = Ind(11,t,i);
                        %removedaysfromstrategy is used to avoid terminal effects (close to T) and hence pick strategies from when the model has converged
                        removedaysfromstrategy = floor((t-1)/365)*365;
                        tyear1 = t-removedaysfromstrategy;  %day in year 1 that t corresponds to
                        
                        % Interpolate continuous variable to find then set strategy
                        newx_cat = ((Ind(1,t,i)-xmin)/(xmax-xmin))*(xcat_max-1)+1;
                        % WITHOUT interpolation - use strategy for first x category below current reserve state
                        intx = max(1,min(floor(newx_cat),xcat_max));%no interpolation for x - use strategy for first x category below current reserve state
                        intE = max(1,min(ceil(E_real),EMax));
                        
                        % On feeding ground (Loc = 1)
                        if Loc == 1
                            % Strategy
                            FGstrategy = strategy(intE,intx,Loc,tyear1); %0=stay and feed, 1= migrate
                            if FGstrategy == 0 %stay on feeding ground
                                Ind(2,t,i) = 10; %strategy
                            else %migrate (FGstrategy = 1)
                                Ind(2,t,i) = 11;
                            end
                            % Act according to strategy
                            if Ind(2,t,i) == 10 %stay on feeding ground - if the optimal strategy for that x and t is == 0
                                Ind(6,t,i) = (1+EffectOfE*(2*((E_real-1)/(EMax-1))-1))*feeding(tyear1); %food intake - ValueE depends on the real environment, E_real
                                Ind(8,t,i) = energeticcost_f(tyear1);
                                newx = min(Ind(1,t,i) + Ind(6,t,i) - energeticcost_f(tyear1),xmax);
                                if t < 3650 || newx >= 0 %alive
                                    Ind(1,t+1,i) = newx;
                                    if t < 3650
                                        Ind( 3,t+1,i) = 1;
                                    else
                                        Ind(3,t+1,i) = Ind(3,t,i)*exp(-mortality_f(tyear1));
                                    end
                                    Ind(11,t+1,i) = Loc; %location
                                    t = t+1;  %next time to evaluate strategy
                                else   %death because insufficient energy (newx <= 0)
                                    Ind(1,t+1,i) = 0;
                                    Ind(3,t+1,i) = 0;
                                    t = tmax; %next time to evaluate strategy
                                end
                                
                            elseif Ind(2,t,i) == 11 %migrate to spawning ground (Ind(2,t,i) = 11)
                                Ind(8,t,i) = energeticcost_m(tyear1);
                                for timestep = 1:migrationduration
                                    Ind( 1,t+timestep,i) = Ind(1,t+timestep-1,i) - energeticcost_m(tyear1+timestep-1);  %reserve state after migration to spawning grounds
                                    if t < 3650 || Ind( 1,t+timestep,i) >= 0 %alive
                                        Ind( 2,t+timestep,i) = 11;
                                        if t < 3650
                                            Ind( 3,t+timestep,i) = 1;
                                        else
                                            Ind( 3,t+timestep,i) = Ind(3,t+timestep-1,i) * exp(-mortality_m(tyear1+timestep-1));
                                        end
                                        Ind( 8,t+timestep,i) = energeticcost_m(tyear1+timestep);
                                        Ind(11,t+timestep,i) = 11;
                                    else %dead
                                        Ind( 1,t+timestep,i) = 0;
                                        Ind( 3,t+timestep,i) = 0;
                                    end
                                end
                                if t < 3650 || Ind( 1,t+migrationduration,i) >= 0 %alive when arriving at spawning ground
                                    Ind(11,t+migrationduration,i) = 2; %location
                                    t = t+migrationduration;
                                else
                                    t = tmax;
                                end
                            end
                            
                            % On spawning ground (Loc = 2)
                        elseif Loc == 2
                            % Strategy
                            SGstrategy = strategy(1,intx,Loc,tyear1); %0=wait, >0=spawn
                            if SGstrategy == 0 %wait on spawning ground
                                Ind(2,t,i) = 20;
                            elseif SGstrategy == ccat_max %spawn everything
                                Ind(2,t,i) = 23;
                                Ind(7,t,i) = 2;
                            else
                                Ind(2,t,i) = 22;
                                Ind(7,t,i) = min((SGstrategy)/(ccat_max-1),1); %optimal clutch as proportion of cmax, Ind(2,t,i)>1 indicates terminal spawning (ccat=21)
                            end
                            % Act according to strategy
                            if Ind(2,t,i) == 20 %wait on spawning ground
                                newx = min(Ind(1,t,i) - energeticcost_s(tyear1),xmax);
                                Ind( 8,t,i) = energeticcost_s(tyear1);
                                if t < 3650 || (newx >= 0) %alive
                                    Ind( 1,t+1,i) = max(0., newx);
                                    if t < 3650
                                        Ind( 3,t+1,i) = 1;
                                    else
                                        Ind( 3,t+1,i) = Ind(3,t,i)*exp(-mortality_s(tyear1));
                                    end
                                    Ind(11,t+1,i) = Loc; %Location
                                    t = t+1;
                                else   %death because insufficient energy (newx <= 0)
                                    Ind(1,t+1,i) = 0;
                                    Ind(3,t+1,i) = 0;
                                    t = tmax;
                                end
                                
                            else %spawn
                                
                                spawneverything = Ind(1,t,i); %max energy available for spawning (J)
                                spawnandreturn = Ind(1,t,i) - sum(energeticcost_m(tyear1:tyear1+migrationduration)); % (J) if return to feeding ground - max energy available for spawning
                                
                                if Ind(7,t,i) > 1 && t >= 3650 %spawn everything and that's end of life, Ind(7,t,i) = 2 (but only if after 10 years of simulation)
                                    c = spawneverything;
                                    Ind(4,t,i) = Ind(7,t,i); %proportion of cmax spawned
                                    Ind(5,t,i) = spawneverything;  %energy actually spawned (J)
                                    Ind(7,t,i) = 2;  %flag for final spawning and death (ccat 21)
                                    Ind(8,t,i) = 0;
                                    Ind(9,t,i) = Ind(9,t,i)+Ind(3,t,i)*spawneverything*offspringfitness(tyear1);
                                    Ind(10,t,i) = 0;
                                    Ind(3,t,i) = 0; %dead
                                    t = tmax;
                                    
                                    % Keep individuals alive if t < 10 years --> Spawn and return
                                elseif Ind(7,t,i) > 1 && t < 3650
                                    c = 0.5*spawnandreturn;  %J, spawn part of max energy available for spawning if returning to feeding ground
                                    Ind(4,t,i) = 0.5;
                                    Ind(5,t,i) = 0.5*spawnandreturn;  %J, same as c
                                    Ind(1,t,i) = Ind(1,t,i) - c; %reserve state after spawning
                                    Ind(8,t,i) = 0;
                                    Ind(9,t:tmax,i) = Ind(9,t,i)+Ind(3,t,i)*c*offspringfitness(tyear1);  %cumulative fitness upon return to feeding ground
                                    Ind(10,t,i) = 0;
                                    %migrate back to feeding ground - t < 3650 hence keep alive
                                    for timestep = 1:migrationduration
                                        Ind(1,t+timestep,i) = Ind(1,t+timestep-1,i) - energeticcost_m(tyear1+timestep-1);  %reserve state after migrating back
                                        Ind(2,t+timestep,i) = 21;
                                        Ind(3,t+timestep,i) = 1;
                                        Ind(8,t+timestep,i) = energeticcost_m(tyear1+timestep);
                                        Ind(11,t+timestep,i) = 21;
                                    end
                                    Ind(11,t+migrationduration,i) = 1; %back on feeding ground
                                    t = t+migrationduration;
                                    
                                else  %Spawn and return
                                    c = Ind(7,t,i)*spawnandreturn;  %J, spawn part of max energy available for spawning if returning to feeding ground
                                    Ind(4,t,i) = Ind(7,t,i);
                                    Ind(5,t,i) = Ind(7,t,i)*spawnandreturn;  %J, same as c
                                    Ind(1,t,i) = Ind(1,t,i) - c; %reserve state after spawning
                                    Ind(8,t,i) = 0;
                                    Ind(9,t:tmax,i) = Ind(9,t,i)+Ind(3,t,i)*c*offspringfitness(tyear1);  %cumulative fitness upon return to feeding ground
                                    Ind(10,t,i) = 0;
                                    % Return to feeding ground
                                    for timestep = 1:migrationduration
                                        Ind(1,t+timestep,i) = Ind(1,t+timestep-1,i) - energeticcost_m(tyear1+timestep-1);  %reserve state after migrating back
                                        if  t < 3650 || Ind(1,t+timestep,i) > 0 %alive
                                            Ind(2,t+timestep,i) = 21;
                                            if t < 3650
                                                Ind(3,t+timestep,i) = 1;
                                            else
                                                Ind(3,t+timestep,i) = Ind(3,t+timestep-1,i) * exp(-mortality_m(tyear1+timestep-1)); %survival probability after migrating back
                                            end
                                            Ind(8,t+timestep,i) = energeticcost_m(tyear1+timestep);
                                            Ind(11,t+timestep,i) = 21;
                                        else %dead
                                            Ind(1,t+timestep,i) = 0;
                                            Ind(3,t+timestep,i) = 0;
                                        end
                                    end
                                    if t < 3650 || Ind(1,t+migrationduration,i) >= 0
                                        Ind(11,t+migrationduration,i) = 1; %back on feeding ground
                                        t = t+migrationduration;
                                    else
                                        t = tmax;
                                    end
                                    
                                end
                            end
                        end  %Loc
                    end  %t
                    
                    
                    %% End forward simulation (except over i) 
                    
                    %Store spawning episodes (time and energy spawned) for each individual in separate matrix - after 10 years of simulation              
                    Spawning_episodes(1:2,1:yrs_simulated) = 0; %1:yrs_simulated allows for up to 2 spawnings a year
                    
                    Episode = 1;
                    for t = 3650:tmax %only include last 10 years in analysis(tmax is timespan for forward simulation)
                        if (Ind(2,t,i) > 21)
                            Spawning_episodes(1,Episode)= t; %Timestep where spawning takes place
                            Spawning_episodes(2,Episode)= Ind(5,t,i); %Energy spawned
                            Episode = Episode + 1;
                        end
                    end
                    
                    %if no spawnings the individual dies before spawning --> continue to loop for next i
                    if i < maxind && sum(Spawning_episodes(1,:)) == 0
                        dead_initial = dead_initial + 1;
                        continue
                        %if i = maxind and the individual dies before spawning --> do not continue
                    elseif i == maxind && sum(Spawning_episodes(1,:)) == 0
                        dead_initial = dead_initial + 1;
                        Spawning_episodes(1,:) = 0;
                        Spawning_episodes(2,:) = 0;
                        spawningdays = 0; %no spawning days
                        SD_all_ind = SD_all_ind; %no spawning days added to array containing the spawning days for all individuals
                        %if individual has spawning events in last 10 years
                    else
                        spawn_day = nonzeros(Spawning_episodes(1,:)); 
                        spawn_energy = nonzeros(Spawning_episodes(2,:));
                        removedays(length(spawn_day)) = 0;
                        removedays(:) = floor((spawn_day(:)-1)/365)*365;
                        spawningdays = spawn_day' - removedays; %spawningdays as day in year 1
                        %array containing the predicted spawning days for all individuals
                        SD_all_ind = [SD_all_ind,spawningdays];
                    end
                    
                    clear spawn_day removedays;
                    
                    %if i = maxind and no spawnings give zeros
                    if i == maxind && sum(spawningdays) == 0
                        sum_spawndays_ind(:,i) = 0; %number of spawning on each day
                        sum_energy_ind(:,i) = 0;
                        max_energy_ind(t,i) = 0;
                    else
                        %for each individual, record number of spawnings and total energy spawned for each day of the year
                        for t = 1:365
                            logic_t = (spawningdays == t);
                            sum_spawndays_ind(t,i) = sum(logic_t); %number of spawning on each day
                            sum_energy_ind(t,i) = sum(logic_t.*spawn_energy');
                            max_energy_ind(t,i) = max(logic_t.*spawn_energy');
                        end
                    end
                    
                    clear logic_t spawn_energy spawningdays;
                    
                end %i
                
                %% End forward simulation - Code below is for plots
                
                sum_energy_all_ind(365) = 0;
                nbr_spawnings(365) = 0;
                mean_energy_per_spawnday(365) = 0;
                
                % Calculate the mean energy spawned for each spawning day of the year (over total number of spawning events for all individuals)
                for t = 1:365
                    sum_energy_all_ind(t) = sum(sum_energy_ind(t,:)); %sum of energy for all individuals on day t
                    nbr_spawnings(t) = sum(sum_spawndays_ind(t,:)); %number of spawnings for all individuals on day t
                    mean_energy_per_spawnday(t) = sum_energy_all_ind(t)/nbr_spawnings(t); %mean energy per spawning day for all individuals
                end
                
                % Save mean energy spawned per day of the year as proportion of max energy spawned for the FI peak day
                max_energy_FIpeak = max(max(max_energy_ind(:,:)));
                surpluspeak_SD_energy(((FIpeak-1)*365)+1:FIpeak*365,FMvalue,Mean,Ampl) = mean_energy_per_spawnday./max_energy_FIpeak; %as linear array
                
                clear max_energy_ind mean_energy_per_spawnday;
                
                % Tabulate the spawning events (over total number of spawning events for all individuals)
                % If no spawning days predicted move on to next FIpeak loop
                if sum(SD_all_ind) == 0
                    freq_table(1:365,1:4) = 0;
                else
                    freq_table = tabulate(nonzeros(SD_all_ind));
                    sum_days = sum(freq_table(:,2));
                    add_days = linspace(length(freq_table)+1,365,365-length(freq_table));  %make table contain 365 days
                    freq_table(length(freq_table)+1:365,1) = add_days(:);
                    freq_table(length(freq_table)+1:365,2:3) = 0;
                    freq_table(:,4) = freq_table(:,2)./sum_days; %(yrs_simulated*maxind);  %calculate frequancy of spawnings for each day
                end
                
                clear sum_days add_days;
                
                % Spawning frequency
                surpluspeak_SD_frequency(((FIpeak-1)*365)+1:FIpeak*365,FMvalue,Mean,Ampl) = freq_table(:,4);%as linear array
                
                % Spawning days
                start = (365*(FIpeak-1))+1;
                stop = FIpeak*365;
                
                for step = start:stop
                    remove = floor((step-1)/365)*365;
                    step_year1 = step - remove;
                    if freq_table(step_year1,2) > 0
                        surpluspeak_SD(step,FMvalue,Mean,Ampl) = freq_table(step_year1,1); %as linear array (for plotting predicted spawning days for ALL FI peaks)
                    end
                end
                
                clear remove step_year1 freq_table;
                
                % Create linear array of x values for plotting daily spawning frequencies against each FMvalue
                surpluspeak_plotX(((FIpeak-1)*365)+1:FIpeak*365,FMvalue,Mean,Ampl) = surplus_peakday(FIpeak);
                
                % Record individuals that are dead already at first timestep and hence are left out of the analysis
                dead_initial_scen(FIpeak,FMvalue,Mean,Ampl) = dead_initial;
                
                
            end %FIpeak
        end %Ampl
    end %Mean
end %FMvalue


%% CODE FOR PLOTTING %%

FIpeak_SD = surpluspeak_SD;
FIpeak_SD_frequency = surpluspeak_SD_frequency;
FIpeak_SD_energy = surpluspeak_SD_energy;
FIpeak_plotX = surpluspeak_plotX;

FIpeak_SD(FIpeak_SD==0)=NaN;
FIpeak_SD_frequency(FIpeak_SD_frequency==0)=NaN;
FIpeak_SD_energy(FIpeak_SD_energy==0)=NaN;

FI_peak = 1:365;
FI_trough_first(1:365) = 366
FI_trough_first(1:182) = FI_peak(1:182)+182;
FI_trough_second(1:365) = 0;
FI_trough_second(183:365) = FI_peak(183:365)-182;

% POPULATION PLOTS FOR A LOW, MED, AND HIGH MORTALITY RATE

%Low mortality
figure
ax = tight_subplot(3,3,0.02,[0.04 0.02],[0.06 0.01]) 
axes(ax(1));
scatter(FIpeak_plotX(:,1,1,1),FIpeak_SD(:,1,1,1), 2000*FIpeak_SD_frequency(:,1,1,1), FIpeak_SD_energy(:,1,1,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % ;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','r','linestyle',':');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('Low Mean - Energy intake');
ylabel({'{\bf Low Amplitude - Energy intake}';'{\fontsize{1}}';'Spawning day'});
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
axes(ax(2));
scatter(FIpeak_plotX(:,1,2,1),FIpeak_SD(:,1,2,1), 2000*FIpeak_SD_frequency(:,1,2,1), FIpeak_SD_energy(:,1,2,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('Med Mean - Energy intake');
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
axes(ax(3));
scatter(FIpeak_plotX(:,1,3,1),FIpeak_SD(:,1,3,1), 2000*FIpeak_SD_frequency(:,1,3,1), FIpeak_SD_energy(:,1,3,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('High Mean - Energy intake');
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);

axes(ax(4));
scatter(FIpeak_plotX(:,1,1,2),FIpeak_SD(:,1,1,2), 2000*FIpeak_SD_frequency(:,1,1,2), FIpeak_SD_energy(:,1,1,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
ylabel({'{\bfMedium Amplitude - Energy intake}';'';'Spawning day'});
axes(ax(5));
scatter(FIpeak_plotX(:,1,2,2),FIpeak_SD(:,1,2,2), 2000*FIpeak_SD_frequency(:,1,2,2), FIpeak_SD_energy(:,1,2,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
axes(ax(6));
scatter(FIpeak_plotX(:,1,2,3),FIpeak_SD(:,1,3,2), 2000*FIpeak_SD_frequency(:,1,3,2), FIpeak_SD_energy(:,1,3,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);

axes(ax(7));
scatter(FIpeak_plotX(:,1,1,3),FIpeak_SD(:,1,1,3), 2000*FIpeak_SD_frequency(:,1,1,3), FIpeak_SD_energy(:,1,1,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
ylabel({'{\bfHigh Amplitude - Energy intake}';'';'Spawning day'});
axes(ax(8));
scatter(FIpeak_plotX(:,1,2,3),FIpeak_SD(:,1,2,3), 2000*FIpeak_SD_frequency(:,1,2,3), FIpeak_SD_energy(:,1,2,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
xlabel('Peak day for Energy intake intake');
axes(ax(9));
scatter(FIpeak_plotX(:,1,3,3),FIpeak_SD(:,1,3,3), 2000*FIpeak_SD_frequency(:,1,3,3), FIpeak_SD_energy(:,1,3,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
hold off;

%Med mortality
figure
ax = tight_subplot(3,3,0.02,[0.06 0.04],[0.06 0.01]) %(3x3,[horizontalgap verticalgap],[bottomgap topgap],[leftgap rightgap])
axes(ax(1));
scatter(FIpeak_plotX(:,2,1,1),FIpeak_SD(:,2,1,1), 2000*FIpeak_SD_frequency(:,2,1,1), FIpeak_SD_energy(:,2,1,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('Low Mean - Energy intake');
ylabel({'{\bfLow Amplitude - Energy intake}';'';'Spawning day'});
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
axes(ax(2));
scatter(FIpeak_plotX(:,2,2,1),FIpeak_SD(:,2,2,1), 2000*FIpeak_SD_frequency(:,2,2,1), FIpeak_SD_energy(:,2,2,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('Med Mean - Energy intake');
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
axes(ax(3));
scatter(FIpeak_plotX(:,2,3,1),FIpeak_SD(:,2,3,1), 2000*FIpeak_SD_frequency(:,2,3,1), FIpeak_SD_energy(:,2,3,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('High Mean - Energy intake');
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);

axes(ax(4));
scatter(FIpeak_plotX(:,2,1,2),FIpeak_SD(:,2,1,2), 2000*FIpeak_SD_frequency(:,2,1,2), FIpeak_SD_energy(:,2,1,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
ylabel({'{\bfMedium Amplitude - Energy intake}';'';'Spawning day'});
axes(ax(5));
scatter(FIpeak_plotX(:,2,2,2),FIpeak_SD(:,2,2,2), 2000*FIpeak_SD_frequency(:,2,2,2), FIpeak_SD_energy(:,2,2,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
axes(ax(6));
scatter(FIpeak_plotX(:,2,2,3),FIpeak_SD(:,2,3,2), 2000*FIpeak_SD_frequency(:,2,3,2), FIpeak_SD_energy(:,2,3,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);

axes(ax(7));
scatter(FIpeak_plotX(:,2,1,3),FIpeak_SD(:,2,1,3), 2000*FIpeak_SD_frequency(:,2,1,3), FIpeak_SD_energy(:,2,1,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
ylabel({'{\bfHigh Amplitude - Energy intake}';'';'Spawning day'});
axes(ax(8));
scatter(FIpeak_plotX(:,2,2,3),FIpeak_SD(:,2,2,3), 2000*FIpeak_SD_frequency(:,2,2,3), FIpeak_SD_energy(:,2,2,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
xlabel('Peak day for Energy intake intake');
axes(ax(9));
scatter(FIpeak_plotX(:,2,3,3),FIpeak_SD(:,2,3,3), 2000*FIpeak_SD_frequency(:,2,3,3), FIpeak_SD_energy(:,2,3,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
hold off;

%High mortality
figure
ax = tight_subplot(3,3,0.02,[0.06 0.04],[0.06 0.01]) %(3x3,[horizontalgap verticalgap],[bottomgap topgap],[leftgap rightgap])
axes(ax(1));
scatter(FIpeak_plotX(:,3,1,1),FIpeak_SD(:,3,1,1), 2000*FIpeak_SD_frequency(:,3,1,1), FIpeak_SD_energy(:,3,1,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('Low Mean - Energy intake');
ylabel({'{\bfLow Amplitude - Energy intake}';'';'Spawning day'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
axes(ax(2));
scatter(FIpeak_plotX(:,3,2,1),FIpeak_SD(:,3,2,1), 2000*FIpeak_SD_frequency(:,3,2,1), FIpeak_SD_energy(:,3,2,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('Med Mean - Energy intake');
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
axes(ax(3));
scatter(FIpeak_plotX(:,3,3,1),FIpeak_SD(:,3,3,1), 2000*FIpeak_SD_frequency(:,3,3,1), FIpeak_SD_energy(:,3,3,1), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
title('High Mean - Energy intake');
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);

axes(ax(4));
scatter(FIpeak_plotX(:,3,1,2),FIpeak_SD(:,3,1,2), 2000*FIpeak_SD_frequency(:,3,1,2), FIpeak_SD_energy(:,3,1,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
ylabel({'{\bfMedium Amplitude - Energy intake}';'';'Spawning day'});
axes(ax(5));
scatter(FIpeak_plotX(:,3,2,2),FIpeak_SD(:,3,2,2), 2000*FIpeak_SD_frequency(:,3,2,2), FIpeak_SD_energy(:,3,2,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
axes(ax(6));
scatter(FIpeak_plotX(:,3,3,2),FIpeak_SD(:,3,3,2), 2000*FIpeak_SD_frequency(:,3,3,2), FIpeak_SD_energy(:,3,3,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca,'XtickLabel',[]);
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);

axes(ax(7));
scatter(FIpeak_plotX(:,3,1,3),FIpeak_SD(:,3,1,3), 2000*FIpeak_SD_frequency(:,3,1,3), FIpeak_SD_energy(:,3,1,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
xlim([0 365]);
ylim([0 365]);
ylabel({'{\bfHigh Amplitude - Energy intake}';'';'Spawning day'});
axes(ax(8));
scatter(FIpeak_plotX(:,3,2,3),FIpeak_SD(:,3,2,3), 2000*FIpeak_SD_frequency(:,3,2,3), FIpeak_SD_energy(:,3,2,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
xlabel('Peak day for Energy intake intake');
axes(ax(9));
scatter(FIpeak_plotX(:,3,3,3),FIpeak_SD(:,3,3,3), 2000*FIpeak_SD_frequency(:,3,3,3), FIpeak_SD_energy(:,3,3,3), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','m');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); hold on; 
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
xlim([0 365]);
ylim([0 365]);
hold off;

% Plot and save Figure 4 - Low, Med, High energy intake at Med mortality rate

fig2 = figure('PaperPosition',[.01 .01 8 7]) 
ax = tight_subplot(1,3,0.01,[0.3 0.3],[0.06 0.02]) %(3x3,[horizontalgap verticalgap],[bottomgap topgap],[leftgap rightgap])
axes(ax(1));
scatter(FIpeak_plotX(:,2,1,2),FIpeak_SD(:,2,1,2), 1000*FIpeak_SD_frequency(:,2,1,2), FIpeak_SD_energy(:,2,1,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','r','linestyle',':');
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); 
hold on;
plot([365/12*5.4 365/12*6.4], [10 10], 'color','k')
hold on;
plot([365/12*5.4 365/12*6.4], [355 355], 'color','k')
hold on
plot([365/12*5.4 365/12*5.4], [10 355], 'color','k')
hold on
plot([365/12*6.4 365/12*6.4], [10 355], 'color','k')
xlim([0 365]);
ylim([0 365]);
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
ylabel({'\fontsize{13}Spawning day'});
title({'{\fontsize{13}\rm Low}'});
axes(ax(2));
scatter(FIpeak_plotX(:,2,2,2),FIpeak_SD(:,2,2,2), 1000*FIpeak_SD_frequency(:,2,2,2), FIpeak_SD_energy(:,2,2,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); % colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday],'color','r','linestyle',':')
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); 
hold on;
plot([365/12*5.4 365/12*6.4], [10 10], 'color','k')
hold on;
plot([365/12*5.4 365/12*6.4], [355 355], 'color','k')
hold on
plot([365/12*5.4 365/12*5.4], [10 355], 'color','k')
hold on
plot([365/12*6.4 365/12*6.4], [10 355], 'color','k')
xlim([0 365]);
ylim([0 365]);
xlabel([{'\fontsize{13}Peak day for Energy intake'}]);
title({'{\fontsize{13}\bf Energy intake}';'';'{\fontsize{13}\rm Medium}'});
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);
axes(ax(3));
scatter(FIpeak_plotX(:,2,3,2),FIpeak_SD(:,2,3,2), 1000*FIpeak_SD_frequency(:,2,3,2), FIpeak_SD_energy(:,2,3,2), 'filled', 'jitter','on', 'jitterAmount', 4), caxis([0 1]); %colorbar;
hold on;
plot([1 365], [OF_peakday OF_peakday], 'color','r','linestyle',':')
hold on;
plot(1:365, FI_peak, 'color',[0 0.4 0]); 
hold on;
plot([365/12*5.4 365/12*6.4], [10 10], 'color','k')
hold on;
plot([365/12*5.4 365/12*6.4], [355 355], 'color','k')
hold on
plot([365/12*5.4 365/12*5.4], [10 355], 'color','k')
hold on
plot([365/12*6.4 365/12*6.4], [10 355], 'color','k')
set(gca,'XtickLabel',[],'YtickLabel',[]);
xlim([0 365]);
ylim([0 365]);
title({' ';'{\fontsize{13}\rm High}'});
set(gca, 'XTick', [0:365/12:(365/12)*11], 'XTickLabel', {'J','F','M','A','M','J','J','A','S','O','N','D'});
set(gca, 'YTick', [0:365/12:(365/12)*11], 'YTickLabel', []);

fig.PaperPositionMode = 'manual';
orient(fig2,'landscape')
print(fig2,'Fig 4','-dpdf')





